import React, { useEffect, useState, useCallback } from "react";
import { BrowserRouter as Router, Route, Routes } from "react-router-dom";
import Filters from "./components/Filters";
import Gallery from "./components/Gallery";
import Favorites from "./components/Favorites";
import BreedInfoPage from "./components/BreedInfoPage";
import "./App.css";
import { debounce } from "lodash";
const apikey ="live_8bnMZatSzkOR7eyT6o0iwDmXQuTxPI3deVWy0KY2ABxDkTMJdTYZ13S9lVFmrZRO"
const App = () => {
  const [cats, setCats] = useState([]);
  const [loading, setLoading] = useState(true);
  const [filters, setFilters] = useState({ breed: "", hairLength: "" ,origin:"" });
  const [favorites, setFavorites] = useState(JSON.parse(localStorage.getItem("favorites")) || []);
  const [page, setPage] = useState(1);
  const [randomCat,setRandomCat]=useState(null);


  useEffect(() => {
    const fetchCats = async () => {
      try {
        setLoading(true);
        let queryParams = `?limit=20&page=${page}`;

        if (filters.breed) queryParams += `&breed_ids=${filters.breed}`;
        if (filters.hairLength) queryParams += `&hair_length=${filters.hairLength}`;
        if (filters.origin) queryParams += `&origin=${filters.origin}`;

        const response = await fetch(
          `https://api.thecatapi.com/v1/images/search${queryParams}`,
          {
            headers: { "x-api-key": apikey },
          }
        );

        if (!response.ok) throw new Error("Failed to fetch data");

        const data = await response.json();
      setCats((prevCats) => (page === 1 ? data : [...prevCats, ...data]));
      }
      catch (err) {
        console.error(err.message);
      } finally {
        setLoading(false);
      }
    };
  

    fetchCats();
  }, [filters, page]);
  
  const fetchRandomCat = async () => {
    try {
      const response = await fetch(
        `https://api.thecatapi.com/v1/images/search?limit=1`,
        {
          headers: { "x-api-key": apikey },
        }
      );

      if (!response.ok) throw new Error("Failed to fetch random cat");

      const data = await response.json();
      setRandomCat(data[0]);
    } catch (err) {
      console.error(err.message);
    }
  };

  const debouncedHandleFilterChange = useCallback(
    debounce((updatedFilters) => {
      setFilters(updatedFilters);
      setPage(1); 
    }, 300),
    []
  );

  const handleFilterChange = (e) => {
    const { name, value } = e.target;
    debouncedHandleFilterChange({ ...filters, [name]: value });
    
  };

  return (
    <Router>
      <Routes>
        <Route
          path="/"
          element={
            <div>
              <h1>Cat Gallery</h1>
              <Filters filters={filters} onFilterChange={handleFilterChange} />
              
              <Gallery
                cats={cats}
                loading={loading}
                onLoadMore={() => setPage((prev) => prev + 1)}
                onAddFavorite={(cat) => setFavorites([...favorites, cat])}
              />
              <button className="random-cat-button" onClick={fetchRandomCat}>
                Show Me a Random Cat!
              </button>
              {randomCat && (
                <div className="random-cat">
                  <h2>Random Cat</h2>
                  <img
                    src={randomCat.url}
                    alt="Random Cat"
                    className="random-cat-image"
                  />
                </div>
              )}
              <Favorites
                favorites={favorites}
                onRemoveFavorite={(id) =>
                  setFavorites(favorites.filter((cat) => cat.id !== id))
                }
              />
            </div>
          }
        />
        <Route path="/breed/:id" element={<BreedInfoPage />} />
      </Routes>
    </Router>
  );
};
export default App;
