import React, { useEffect, useState } from "react";
import { useParams, useNavigate } from "react-router-dom";

const API_URL = "https://api.thecatapi.com/v1";
const API_KEY = "live_8bnMZatSzkOR7eyT6o0iwDmXQuTxPI3deVWy0KY2ABxDkTMJdTYZ13S9lVFmrZRO"; 

const BreedInfoPage = () => {
  const { id } = useParams();
  const navigate = useNavigate();
  const [breed, setBreed] = useState(null);
  const [image, setImage] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState("");

  useEffect(() => {
    const fetchBreedInfo = async () => {
      try {
        setLoading(true);

      
        const breedResponse = await fetch(`${API_URL}/breeds/${id}`, {
          headers: { "x-api-key": API_KEY },
        });

        if (!breedResponse.ok) throw new Error("Failed to fetch breed information.");
        const breedData = await breedResponse.json();
        setBreed(breedData);

       
        const imageResponse = await fetch(`${API_URL}/images/search?breed_ids=${id}&limit=1`, {
          headers: { "x-api-key": API_KEY },
        });

        if (!imageResponse.ok) throw new Error("Failed to fetch breed image.");
        const imageData = await imageResponse.json();
        if (imageData.length > 0) {
          setImage(imageData[0].url); 
        }
      } catch (err) {
        setError(err.message);
      } finally {
        setLoading(false);
      }
    };

    fetchBreedInfo();
  }, [id]);

  if (loading) return <p>Loading breed information...</p>;
  if (error) return <p>Error: {error}</p>;

  return (
    <div className="breed-info-page">
      <button onClick={() => navigate(-1)}>Back</button>
      <h2>{breed?.name || "Unknown Breed"}</h2>
      
      {image && <img src={image} alt={breed?.name} loading="lazy" style={{ Width: "200px",height:"200px", alignItems:"center" }} />}
      
      <p>
        <strong>Origin:</strong> {breed?.origin || "Unknown"}
      </p>
      <p>
        <strong>Weight:</strong> {`Imperial: ${breed?.weight?.imperial || "N/A"} | Metric: ${breed?.weight?.metric || "N/A"}`}
      </p>
      <p>
        <strong>Temperament:</strong> {breed?.temperament || "Unknown"}
      </p>
      <p>
        <strong>Lifespan:</strong> {breed?.life_span || "Unknown"}
      </p>
      <p>
        <strong>Description:</strong> {breed?.description || "No description available."}
      </p>
      {breed?.wikipedia_url && (
        <p>
          <strong>Learn More:</strong>{" "}
          <a href={breed.wikipedia_url} target="_blank" rel="noopener noreferrer">
            Wikipedia
          </a>
        </p>
      )}
    </div>
  );
};

export default BreedInfoPage;
